<?php
/*
Plugin Name: Editor's Columns
Plugin URI: http://wpgurus.net/
Description: Adds several new columns to the post table to help editors get rid of poor-quality content quickly.
Version: 0.1
Author: Hassan Akhtar
Author URI: http://wpgurus.net/
License: GPL2
*/

/**********************************************
*
* Setup the plugin options
*
***********************************************/

function wpec_install(){
	$options_set = get_option('wpec_all_settings');
	if(!$options_set){
		$options = array(
			'random_sentence_count' => 3,
			'active_columns' 		=> array('word_count'=>1, 'links'=>1,'random_excerpts'=>0, 'media'=>1, 'thumb'=>1),
			'minimum_role_view' 	=> 'moderate_comments'
		);
		update_option( 'wpec_all_settings', $options );
	}
}
register_activation_hook( __FILE__, 'wpec_install' );

/**********************************************
*
* Adding new columns to edit.php page
*
***********************************************/

function wpec_add_admin_column_headers($headers){
	$plugin_options = get_option('wpec_all_settings');
	if(!current_user_can($plugin_options['minimum_role_view'])) return;

	if($plugin_options['active_columns']['word_count']) $headers['wpec_word_count_column'] = "Words";
	if($plugin_options['active_columns']['links']) $headers['wpec_links_column'] = "Links";
	if($plugin_options['active_columns']['media']) $headers['wpec_media_column'] = "Images";
	if($plugin_options['active_columns']['thumb']) $headers['wpec_thumb_column'] = "Thumb";
	if($plugin_options['active_columns']['random_excerpts']) $headers['wpec_random_excerpts_column'] = "Random Excerpts";
	return $headers;
}
add_filter( 'manage_posts_columns', 'wpec_add_admin_column_headers', 10, 2 );

function wpec_trim_string($string){
	if($string == '' || $string == null || $string == false || ctype_space($string))
		return false;
	return true;
}

function wpec_add_admin_column_contents($header, $something){
	global $post;
	$post_content = $post->post_content;
	$plugin_options = get_option('wpec_all_settings');

	if(!$post_content){
		echo "N/A";
	}
	elseif($header == 'wpec_word_count_column'){
		echo str_word_count($post_content);
	}
	elseif($header == 'wpec_links_column'){
		$links_dom = new DOMDocument( "1.0", "ISO-8859-15" );
		$links_dom->loadHTML($post_content);
		$links = $links_dom->getElementsByTagName('a');
		if($links->length > 0)
			foreach ($links as $key => $link) {
				echo $links_dom->saveHTML($link);
			}
		else
			echo 'None';
	}
	elseif($header == 'wpec_media_column'){
		$image_dom = new DOMDocument( "1.0", "ISO-8859-15" );
		$image_dom->loadHTML($post_content);
		$images = $image_dom->getElementsByTagName('img');
		echo $images->length;
	}
	elseif($header == 'wpec_thumb_column'){
		echo (has_post_thumbnail($post->ID))?'Yes':'No';
	}
	elseif($header == 'wpec_random_excerpts_column'){
		$post_content		= strip_tags($post_content);
		$sentences 			= array_values(array_filter( preg_split('/[.?!]/', $post_content), 'wpec_trim_string' ));
		$sentence_count 	= count($sentences);
		$selected_sentences = array();
		$toshow 			= $plugin_options['random_sentence_count'];
		$sector_size 		= floor($sentence_count/$toshow);
		$start_rand 		= 0;
		$end_rand			= $sector_size-1;
		if($sentence_count<=$toshow)
			$selected_sentences = $sentences;
		else{
			for($i=0;$i<$toshow && $i<$sentence_count;$i++){
				$index 		= rand($start_rand, $end_rand);
				$start_rand = $end_rand+1;
				$end_rand 	+= $sector_size;
				if(isset($sentences[$index]))
					$selected_sentences[$i] = $sentences[$index];
			}
		}
		$selected_sentences = implode(' ...', $selected_sentences);
		echo $selected_sentences;
	}
}
add_filter( 'manage_posts_custom_column', 'wpec_add_admin_column_contents', 10, 2 );

function wpec_custom_admin_head(){
	echo '<style>.fixed .column-wpec_word_count_column {width: 4em;} .fixed .column-wpec_links_column {width: 7em;}.column-wpec_links_column a{border-bottom: 1px dashed #E7E7E7;display: block;margin-bottom: 5px;padding-bottom: 5px;}.fixed .column-wpec_media_column {width: 4em;}.column-wpec_links_column img {height: auto;width: 60px;}.fixed .column-wpec_thumb_column{width:4em;}</style>';
}
add_action('admin_head', 'wpec_custom_admin_head');

/**********************************************
*
* Load the option panel
*
***********************************************/

include('inc/options-panel.php');