<?php
/*
The settings page
*/

function wpec_menu_item() {
	global $wpec_settings_page_hook;
    $wpec_settings_page_hook = add_plugins_page(
        'Editor\'s Columns',         			   	// The title to be displayed in the browser window for this page.
        'Editor\'s Columns',					    // The text to be displayed for this menu item
        'administrator',            				// Which type of users can see this menu item  
        'wpec_settings',    						// The unique ID - that is, the slug - for this menu item
        'wpec_render_settings_page'     			// The name of the function to call when rendering this menu's page  
    );
}
add_action( 'admin_menu', 'wpec_menu_item' );

function wpec_scripts_styles($hook) {
	global $wpec_settings_page_hook;
	if( $wpec_settings_page_hook != $hook )
		return;
	wp_enqueue_style("options_panel_stylesheet", plugins_url( "static/css/options-panel.css" , dirname(__FILE__) ), false, "1.0", "all");
	wp_enqueue_script("options_panel_script", plugins_url( "static/js/options-panel.js" , dirname(__FILE__) ), false, "1.0");
	wp_enqueue_script('common');
	wp_enqueue_script('wp-lists');
	wp_enqueue_script('postbox');
}
add_action( 'admin_enqueue_scripts', 'wpec_scripts_styles' );

function wpec_render_settings_page() {
?>
<div class="wrap">
<div id="icon-options-general" class="icon32"></div>
<h2>Editor's Columns Settings</h2>
	<?php settings_errors(); ?>
	<div class="clearfix paddingtop20">
		<div class="first ninecol">
			<form method="post" action="options.php">
				<?php settings_fields( 'wpec_settings' ); ?>
				<?php do_meta_boxes('wpec_metaboxes','advanced',null); ?>
				<?php wp_nonce_field( 'closedpostboxes', 'closedpostboxesnonce', false ); ?>
				<?php wp_nonce_field( 'meta-box-order', 'meta-box-order-nonce', false ); ?>
			</form>
		</div>
		<div class="last threecol">
			<div class="side-block">
				Like the plugin? If yes please give it a good rating on WordPress.org.
			</div>
		</div>
	</div>
</div>
<?php }

function wpec_create_options() { 
	
	add_settings_section( 'wpec_settings_section', null, null, 'wpec_settings' );

	add_settings_field(
        'random_sentence_count', '', 'wpec_render_settings_field', 'wpec_settings', 'wpec_settings_section',
		array(
			'title' => 'Number of random sentences to show',
			'desc' => 'How many sentences would you like to show in the random excerpts column?',
			'id' => 'random_sentence_count',
			'type' => 'text',
			'group' => 'wpec_all_settings'
		)
    );

    add_settings_field(
        'active_columns', '', 'wpec_render_settings_field', 'wpec_settings', 'wpec_settings_section',
		array(
			'title' => 'Active Columns',
			'desc' => 'Activate the columns you want to display',
			'id' => 'active_columns',
			'type' => 'multicheckbox',
			'items' => array('word_count'=>'Word Count', 'links'=>'Links','random_excerpts'=>'Random Excerpts','media'=>'Images', 'thumb'=>'Thumbnail'),
			'group' => 'wpec_all_settings'
		)
    );

    add_settings_field(
        'minimum_role_view', '', 'wpec_render_settings_field', 'wpec_settings', 'wpec_settings_section',
		array(
			'title' => 'Minimum access level required to view the columns',
			'desc' => 'What\'s the minimum role that a logged in user needs to have in order to view the columns',
			'id' => 'minimum_role_view',
			'type' => 'select',
			'options' => array("install_plugins" => "Administrator", "moderate_comments" => "Editor", "edit_published_posts" => "Author", "edit_posts" => "Contributor", "read" => "Subscriber"),
			'group' => 'wpec_all_settings'
		)
    );

    // Finally, we register the fields with WordPress 
	register_setting('wpec_settings', 'wpec_all_settings', 'wpec_settings_validation');
	
} // end sandbox_initialize_theme_options 
add_action('admin_init', 'wpec_create_options');

function wpec_settings_validation($input){
	return $input;
}

function wpec_add_meta_boxes(){
	add_meta_box("wpec_all_settings_metabox", 'Settings', "wpec_metaboxes_callback", "wpec_metaboxes", 'advanced', 'default', array('settings_section'=>'wpec_settings_section'));
}
add_action( 'admin_init', 'wpec_add_meta_boxes' );

function wpec_metaboxes_callback($post, $args){
	do_settings_fields( "wpec_settings", $args['args']['settings_section'] );
	submit_button('Save Changes', 'secondary');
}

function wpec_render_settings_field($args){
	$option_value = get_option($args['group']);
?>
	<div class="row clearfix">
		<div class="col colone"><?php echo $args['title']; ?></div>
		<div class="col coltwo">
	<?php if($args['type'] == 'text'): ?>
		<input type="text" id="<?php echo $args['id'] ?>" name="<?php echo $args['group'].'['.$args['id'].']'; ?>" value="<?php echo esc_attr($option_value[$args['id']]); ?>">
	<?php elseif ($args['type'] == 'select'): ?>
		<select name="<?php echo $args['group'].'['.$args['id'].']'; ?>" id="<?php echo $args['id']; ?>">
			<?php foreach ($args['options'] as $key=>$option) { ?>
				<option <?php selected($option_value[$args['id']], $key); echo 'value="'.$key.'"'; ?>><?php echo $option; ?></option><?php } ?>
		</select>
	<?php elseif($args['type'] == 'checkbox'): ?>
		<input type="hidden" name="<?php echo $args['group'].'['.$args['id'].']'; ?>" value="0" />
		<input type="checkbox" name="<?php echo $args['group'].'['.$args['id'].']'; ?>" id="<?php echo $args['id']; ?>" value="1" <?php checked($option_value[$args['id']]); ?> />
	<?php elseif($args['type'] == 'textarea'): ?>
		<textarea name="<?php echo $args['group'].'['.$args['id'].']'; ?>" type="<?php echo $args['type']; ?>" cols="" rows=""><?php if ( $option_value[$args['id']] != "") { echo stripslashes(esc_textarea($option_value[$args['id']]) ); } ?></textarea>
	<?php elseif($args['type'] == 'multicheckbox'):
		foreach ($args['items'] as $key => $checkboxitem ):
	?>
		<div>
			<input type="hidden" name="<?php echo $args['group'].'['.$args['id'].']['.$key.']'; ?>" value="0" />
			<input type="checkbox" name="<?php echo $args['group'].'['.$args['id'].']['.$key.']'; ?>" id="<?php echo $args['group'].'['.$args['id'].']['.$key.']'; ?>" value="1" 
			<?php if($key=='reason'){ ?>checked="checked" disabled="disabled"<?php }else{ checked($option_value[$args['id']][$key]); } ?> />
			<label for="<?php echo $args['group'].'['.$args['id'].']['.$key.']'; ?>"><?php echo $checkboxitem; ?></label>
		</div>
	<?php endforeach; ?>
	<?php elseif($args['type'] == 'multitext'):
		foreach ($args['items'] as $key => $textitem ):
	?>
		<label for="<?php echo $args['group'].'['.$args['id'].']['.$key.']'; ?>"><?php echo $textitem; ?></label><br/>
		<input type="text" id="<?php echo $args['group'].'['.$args['id'].']['.$key.']'; ?>" name="<?php echo $args['group'].'['.$args['id'].']['.$key.']'; ?>" value="<?php echo esc_attr($option_value[$args['id']][$key]); ?>"><br/>
	<?php endforeach; endif; ?>
		</div>
		<div class="col colthree"><small><?php echo $args['desc'] ?></small></div>
	</div>
<?php
}

?>